"""
Parses data from MAL,Anilist and themes.moe
"""
from .animelist import ANIMELISTSITES ,AniList, MyAnimeList
from .animethemes import fetch_animethemes
from .dldata import get_download_data
from .parser import get_animethemes
